import * as fs from 'fs';
import * as http from 'http';

export default function saveResponse(
  filePath: string,
  resolve: (fileName: string) => void,
  reject: (reason: string) => void,
  response: http.IncomingMessage,
) {
  //Check that file exists (200 HTTP status code)
  if (response.statusCode !== 200) {
    return reject(`Expected status code 200 but received ${response.statusCode}.`);
  }

  //Remember file size
  //const headerLength = Number(response.headers['content-length']);

  const writeStream = fs.createWriteStream(filePath);

  //If we receive a part of the response, write it to disk
  response.pipe(writeStream);

  //If we finished reading response, check for correctness, then return it
  response.on('end', () => {
    //Check that length is correct
    /*if (totalLength !== headerLength) {
      return reject(`Expected length ${headerLength} but received ${totalLength}.`);
    }*/

    //wait until everything is written to disk, then return file name
    writeStream.end(() => {
      //TODO: this is no longer firing ever since we replaced on('data') event by pipe()
      resolve(filePath);
    });
  });
}
